"""Entities for `io` module."""

from typing import Dict, Set

from graphinder.entities.pool import Url

Results = Dict[str, Set[Url]]
